@@ -143,15 +143,17 @@ class FFmpeg(EventEmitter):
         self._options.output(url, options, **kwargs)
         return self
 
-    def execute(self, stream: Optional[Union[bytes, IO[bytes]]] = None) -> bytes:
+    def execute(self, stream: Optional[Union[bytes, IO[bytes]]] = None, timeout: Optional[float] = None) -> bytes:
         """Execute FFmpeg using specified global options and files.
 
         Args:
             stream: A stream to input to the standard input. Defaults to None.
+            timeout: The maximum number of seconds to wait before returning. Defaults to None.
 
         Raises:
             FFmpegAlreadyExecuted: If FFmpeg is already executed.
             FFmpegError: If FFmpeg process returns non-zero exit status.
+            subprocess.TimeoutExpired: If FFmpeg process does not terminate after `timeout` seconds.
 
         Returns:
             The output to the standard output.
@@ -175,23 +177,24 @@ class FFmpeg(EventEmitter):
             stderr=subprocess.PIPE,
         )
 
-        self._executed = True
-
         with concurrent.futures.ThreadPoolExecutor(max_workers=4) as executor:
+            self._executed = True
             futures = [
                 executor.submit(self._write_stdin, stream),
                 executor.submit(self._read_stdout),
                 executor.submit(self._handle_stderr),
-                executor.submit(self._process.wait),
+                executor.submit(self._process.wait, timeout),
             ]
+            done, pending = concurrent.futures.wait(futures, return_when=concurrent.futures.FIRST_EXCEPTION)
+            self._executed = False
 
-            for future in concurrent.futures.as_completed(futures):
+            for future in done:
                 exception = future.exception()
                 if exception is not None:
                     self._process.terminate()
-                    raise exception
+                    concurrent.futures.wait(pending)
 
-        self._executed = False
+                    raise exception
 
         if self._process.returncode == 0:
             self.emit("completed")
